@@ -24,6 +24,7 @@
 #include "fakeclient.h"
 #include "fakeitemretrievalmanager.h"
 #include "inspectablenotificationcollector.h"
+#include "fakeintervalcheck.h"
 
 #include <QSettings>
 #include <QCoreApplication>
@@ -183,6 +184,17 @@ void FakeAkonadiServer::disableItemRetrievalManager()
 }
 
 bool FakeAkonadiServer::init()
+{
+    try {
+        initFake();
+    } catch (const FakeAkonadiServerException &e) {
+        qWarning() << "Server exception: " << e.what();
+        qFatal("Fake Akonadi Server failed to start up, aborting test");
+    }
+    return true;
+}
+
+void FakeAkonadiServer::initFake()
 {
     qDebug() << "==== Fake Akonadi Server starting up ====";
 
@@ -239,10 +251,9 @@ bool FakeAkonadiServer::init()
         mRetrievalManager = new FakeItemRetrievalManager();
     }
 
-    const QString socketFile = basePath() + QLatin1String("/local/share/akonadi/akonadiserver.socket");
+    mIntervalCheck = new FakeIntervalCheck();
 
     qDebug() << "==== Fake Akonadi Server started ====";
-    return true;
 }
 
 bool FakeAkonadiServer::quit()
@@ -268,6 +279,8 @@ bool FakeAkonadiServer::quit()
         mDataStore->close();
     }
 
+    delete mIntervalCheck;
+
     qDebug() << "==== Fake Akonadi Server shut down ====";
     return true;
 }
@@ -281,7 +294,7 @@ void FakeAkonadiServer::newCmdConnection(quintptr socketDescriptor)
 {
     mConnection = new FakeConnection(socketDescriptor);
 
-    // Connection is it's own thread, so we have to make sure we get collector
+    // Connection is its own thread, so we have to make sure we get collector
     // from DataStore of the Connection's thread, not ours
     NotificationCollector *collector = nullptr;
     QMetaObject::invokeMethod(mConnection, "notificationCollector", Qt::BlockingQueuedConnection,
