@@ -43,6 +43,7 @@
 #include <KSharedConfig>
 
 #include <Kdelibs4ConfigMigrator>
+#include <KAboutData>
 
 #include <QSettings>
 #include <QTimer>
@@ -382,7 +383,7 @@ void AgentBasePrivate::init()
     new Akonadi__ControlAdaptor(q);
     new Akonadi__StatusAdaptor(q);
     if (!KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/"), q, QDBusConnection::ExportAdaptors)) {
-        q->error(i18n("Unable to register object at dbus: %1", KDBusConnectionPool::threadConnection().lastError().message()));
+        Q_EMIT q->error(i18n("Unable to register object at dbus: %1", KDBusConnectionPool::threadConnection().lastError().message()));
     }
 
     mSettings = new QSettings(ServerManager::agentConfigFilePath(mId), QSettings::IniFormat);
@@ -959,12 +960,11 @@ QString AgentBase::parseArguments(int argc, char **argv)
 
 // @endcond
 
-int AgentBase::init(AgentBase *r)
+int AgentBase::init(AgentBase &r)
 {
     KLocalizedString::setApplicationDomain("libakonadi5");
-    int rv = qApp->exec();
-    delete r;
-    return rv;
+    KAboutData::setApplicationData(r.aboutData());
+    return qApp->exec();
 }
 
 int AgentBase::status() const
@@ -1081,6 +1081,11 @@ void AgentBase::doSetOnline(bool online)
     Q_UNUSED(online);
 }
 
+KAboutData AgentBase::aboutData() const
+{
+    return KAboutData(qApp->applicationName(), agentName(), qApp->applicationVersion());
+}
+
 void AgentBase::configure(WId windowId)
 {
     Q_UNUSED(windowId);
