@@ -54,6 +54,7 @@
 
 #include "akonadiagentbase_debug.h"
 #include <KLocalizedString>
+#include <KAboutData>
 
 #include <QHash>
 #include <QTimer>
@@ -603,11 +604,11 @@ QString ResourceBase::parseArguments(int argc, char **argv)
     return identifier;
 }
 
-int ResourceBase::init(ResourceBase *r)
+int ResourceBase::init(ResourceBase &r)
 {
-    int rv = qApp->exec();
-    delete r;
-    return rv;
+    KLocalizedString::setApplicationDomain("libakonadi5");
+    KAboutData::setApplicationData(r.aboutData());
+    return qApp->exec();
 }
 
 void ResourceBasePrivate::slotAbortRequested()
@@ -1312,7 +1313,7 @@ void ResourceBasePrivate::slotCollectionListDone(KJob *job)
         const Collection::List list = static_cast<CollectionFetchJob *>(job)->collections();
         for (const Collection &collection : list) {
             //We also get collections that should not be synced but are part of the tree.
-            if (collection.shouldList(Collection::ListSync) || collection.referenced()) {
+            if (collection.shouldList(Collection::ListSync)) {
                 if (mScheduleAttributeSyncBeforeCollectionSync) {
                     scheduler->scheduleAttributesSync(collection);
                 }
