@@ -82,32 +82,28 @@ public:
     /**
      * Destroys the collection path resolver.
      */
-    ~CollectionPathResolver();
+    ~CollectionPathResolver() override;
 
     /**
      * Returns the collection id. Only valid after the job succeeded.
      */
-    Collection::Id collection() const;
+    Q_REQUIRED_RESULT Collection::Id collection() const;
 
     /**
      * Returns the collection path. Only valid after the job succeeded.
      */
-    QString path() const;
+    Q_REQUIRED_RESULT QString path() const;
 
     /**
      * Returns the path delimiter for collections.
      */
-    static QString pathDelimiter();
+    Q_REQUIRED_RESULT static QString pathDelimiter();
 
 protected:
     void doStart() override;
 
 private:
     Q_DECLARE_PRIVATE(CollectionPathResolver)
-
-    //@cond PRIVATE
-    Q_PRIVATE_SLOT(d_func(), void jobResult(KJob *))
-    //@endcond
 };
 
 }
