@@ -57,22 +57,18 @@ void ConflictHandler::start()
 void ConflictHandler::slotOtherItemFetched(KJob *job)
 {
     if (job->error()) {
-        emit error(job->errorText());   //TODO: extend error message
+        Q_EMIT error(job->errorText());   //TODO: extend error message
         return;
     }
 
     ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
     if (fetchJob->items().isEmpty()) {
-        emit error(i18n("Did not find other item for conflict handling"));
+        Q_EMIT error(i18n("Did not find other item for conflict handling"));
         return;
     }
 
     mConflictingItem = fetchJob->items().at(0);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(this, &ConflictHandler::resolve, Qt::QueuedConnection);
-#else
-    QMetaObject::invokeMethod(this, "resolve", Qt::QueuedConnection);
-#endif
 }
 
 void ConflictHandler::resolve()
@@ -114,16 +110,16 @@ void ConflictHandler::useLocalItem()
 void ConflictHandler::slotUseLocalItemFinished(KJob *job)
 {
     if (job->error()) {
-        emit error(job->errorText());   //TODO: extend error message
+        Q_EMIT error(job->errorText());   //TODO: extend error message
     } else {
-        emit conflictResolved();
+        Q_EMIT conflictResolved();
     }
 }
 
 void ConflictHandler::useOtherItem()
 {
     // We can just ignore the local item here and leave everything as it is.
-    emit conflictResolved();
+    Q_EMIT conflictResolved();
 }
 
 void ConflictHandler::useBothItems()
@@ -137,9 +133,9 @@ void ConflictHandler::useBothItems()
 void ConflictHandler::slotUseBothItemsFinished(KJob *job)
 {
     if (job->error()) {
-        emit error(job->errorText());   //TODO: extend error message
+        Q_EMIT error(job->errorText());   //TODO: extend error message
     } else {
-        emit conflictResolved();
+        Q_EMIT conflictResolved();
     }
 }
 
